==> general_lib-0.0.2.tar.gz: lib/extension/map.dart <==
// ignore_for_file: non_constant_identifier_names

import "list.dart" as listext;
import "regexp.dart" as regexp;

extension GeneralLibExtensionMap on Map {
  Map clone() {
    Map jsonData = {};
    forEach((key, value) {
      if (value is Map) {
        jsonData[key] = value.clone();
      } else if (value is List) {
        jsonData[key] = value.clone();
      } else {
        jsonData[key] = value;
      }
    });
    return jsonData;
  }

  bool hashData(Map data) {
    int count_valid = 0;
    int count_data_same = 0;
    void countValid(Map data_origin) {
      data_origin.forEach((key, value) {
        if (value is Map) {
        } else if (value is List) {
          count_valid++;
        } else {
          count_valid++;
        }
      });
    }

    data.forEach((key, value) {
      if (value is Map) {
        countValid(value);
      } else if (value is List) {
        count_valid++;
      } else {
        count_valid++;
      }
    });

    void countSame(Map data_origin, Map data_old) {
      data_origin.forEach((key, value) {
        if (!data_origin.containsKey(key)) {
          return;
        }
        dynamic value_origin = data_origin[key];
        if (value is RegExp) {
          if (value.hashData(value_origin)) {
            count_data_same++;
          }
        } else if (value is Map) {
          if (value_origin is Map) {
            countSame(value, value_origin);
          }
        } else if (value is List) {
          if (value_origin is List) {
            if (value_origin.hashData(value)) {
              count_data_same++;
            }
          }
        } else {
          if (value_origin == value) {
            count_data_same++;
          }
        }
      });
    }

    data.forEach((key, value) {
      if (!containsKey(key)) {
        return;
      }
      dynamic value_origin = this[key];
      if (value is RegExp) {
        if (value.hashData(value_origin)) {
          count_data_same++;
        }
      } else if (value is Map) {
        if (value_origin is Map) {
          countSame(value, value_origin);
        }
      } else if (value is List) {
        if (value_origin is List) {
          if (value_origin.hashData(value)) {
            count_data_same++;
          }
        }
      } else {
        if (value_origin == value) {
          count_data_same++;
        }
      }
    });

    if (count_valid == 0) {
      return false;
    }
    return (count_valid == count_data_same);
  }

  Map<T, K> removeValueNull<T, K>() {
    forEach((key, value) {
      if (value == null) {
        remove(key);
      }
    });
    return cast<T, K>();
  }

  Map<T, K> filterByKeys<T, K>(List<String> keys,
      {bool isAllowValueNull = true}) {
    Map<T, K> jsonData = {};
    forEach((key, value) {
      if (keys.contains(key)) {
        if (isAllowValueNull) {
          jsonData[key] = value;
        } else {
          if (value != null) {
            jsonData[key] = value;
          }
        }
      }
    });
    return jsonData;
  }

  void removeByKeys(List<String> keys, {bool isAllowValueNull = true}) {
    for (var i = 0; i < keys.length; i++) {
      var key = keys[i];
      if (keys.contains(key)) {
        remove(key);
      }
    }
  }

  void utils_set_datas_void(List datas, dynamic value) {
    dynamic state_data = this;
    for (var index = 0; index < datas.length; index++) {
      dynamic data_key = datas[index];
      if (state_data[data_key] is Map == false) {
        state_data[data_key] = {};
      }
      if (index == datas.length - 1) {
        state_data[data_key] = value;
      }
      state_data = state_data[data_key];
    }
    return;
  }

  void utils_set_data_void(String data, dynamic value) {
    utils_set_datas_void(data.split("."), value);
    return;
  }

  Map utils_set_datas(List datas, value) {
    utils_set_datas_void(datas, value);
    return this;
  }

  Map utils_set_data(dynamic data, value) {
    utils_set_data_void(data, value);
    return this;
  }
}

==> general_lib-0.0.8.tar.gz: lib/extension/map.dart <==
// ignore_for_file: non_constant_identifier_names

import "list.dart" as listext;
import "regexp.dart" as regexp;

extension GeneralLibExtensionMap on Map {
  Map clone() {
    Map jsonData = {};
    forEach((key, value) {
      if (value is Map) {
        jsonData[key] = value.clone();
      } else if (value is List) {
        jsonData[key] = value.clone();
      } else {
        jsonData[key] = value;
      }
    });
    return jsonData;
  }

  bool hashData(Map data) {
    int count_valid = 0;
    int count_data_same = 0;
    void countValid(Map data_origin) {
      data_origin.forEach((key, value) {
        if (value is Map) {
        } else if (value is List) {
          count_valid++;
        } else {
          count_valid++;
        }
      });
    }

    data.forEach((key, value) {
      if (value is Map) {
        countValid(value);
      } else if (value is List) {
        count_valid++;
      } else {
        count_valid++;
      }
    });

    void countSame(Map data_origin, Map data_old) {
      data_origin.forEach((key, value) {
        if (!data_origin.containsKey(key)) {
          return;
        }
        dynamic value_origin = data_origin[key];
        if (value is RegExp) {
          if (value.hashData(value_origin)) {
            count_data_same++;
          }
        } else if (value is Map) {
          if (value_origin is Map) {
            countSame(value, value_origin);
          }
        } else if (value is List) {
          if (value_origin is List) {
            if (value_origin.hashData(value)) {
              count_data_same++;
            }
          }
        } else {
          if (value_origin == value) {
            count_data_same++;
          }
        }
      });
    }

    data.forEach((key, value) {
      if (!containsKey(key)) {
        return;
      }
      dynamic value_origin = this[key];
      if (value is RegExp) {
        if (value.hashData(value_origin)) {
          count_data_same++;
        }
      } else if (value is Map) {
        if (value_origin is Map) {
          countSame(value, value_origin);
        }
      } else if (value is List) {
        if (value_origin is List) {
          if (value_origin.hashData(value)) {
            count_data_same++;
          }
        }
      } else {
        if (value_origin == value) {
          count_data_same++;
        }
      }
    });

    if (count_valid == 0) {
      return false;
    }
    return (count_valid == count_data_same);
  }

  Map<T, K> removeValueNull<T, K>() {
    forEach((key, value) {
      if (value == null) {
        remove(key);
      }
    });
    return cast<T, K>();
  }

  Map<T, K> filterByKeys<T, K>({
    required List<String> keys,
    bool isAllowValueNull = true,
    
  }) {
    Map<T, K> jsonData = {};

    forEach((key, value) {
      if (keys.contains(key)) {
        if (isAllowValueNull) {
          jsonData[key] = value;
        } else {
          if (value != null) {
            jsonData[key] = value;
          }
        }
      }
    });
    return jsonData;
  }

  Map<T, K> filterByKeysFromMapKeys<T, K>({
    required Map<String, dynamic> keys,
    bool isAllowValueNull = true,
  }) {
    return filterByKeys<T, K>(
      keys: keys.keys.toList(),
      isAllowValueNull: isAllowValueNull,
    );
  }

  void removeByKeys(List<String> keys, {bool isAllowValueNull = true}) {
    for (var i = 0; i < keys.length; i++) {
      var key = keys[i];
      if (keys.contains(key)) {
        remove(key);
      }
    }
  }

  void utils_set_datas_void(List datas, dynamic value) {
    dynamic state_data = this;
    for (var index = 0; index < datas.length; index++) {
      dynamic data_key = datas[index];
      if (state_data[data_key] is Map == false) {
        state_data[data_key] = {};
      }
      if (index == datas.length - 1) {
        state_data[data_key] = value;
      }
      state_data = state_data[data_key];
    }
    return;
  }

  void utils_set_data_void(String data, dynamic value) {
    utils_set_datas_void(data.split("."), value);
    return;
  }

  Map utils_set_datas(List datas, value) {
    utils_set_datas_void(datas, value);
    return this;
  }

  Map utils_set_data(dynamic data, value) {
    utils_set_data_void(data, value);
    return this;
  }
}
